@@ -1,4 +1,4 @@
-__version__ = '1.1.0'
+__version__ = '1.1.3'
 
 import requests
 import json
@@ -22,7 +22,7 @@ class StreamBot:
         self.bot_name = bot_name
         self.config = config or StreamBotConfig()
         self.genesis_prompt = genesis_prompt
-        self.messages = [{"role":"system", "content": genesis_prompt}] if genesis_prompt else []
+        self.messages = [{"role":"system", "content": genesis_prompt}]
         self.openai_url = openai_url
         self.model = model
         self.verbosity = verbosity
@@ -60,6 +60,7 @@ class StreamBot:
 
     def add_message(self, message, role="user"):
       self.messages.append({"role": role, "content": message})
+      return self.messages
 
     def chat(self, messages = []):
         reqBody = self.build_req_body(messages)
